"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LOG_MSG = exports.DEFAULT_LOG_PREFIX = exports.prepareMatomoDimensions = void 0;
/* to transform existing event properties to matomo dimensions */
const prepareMatomoDimensions = (eventProperties) => {
    return Object.entries(eventProperties).reduce((evProps, [k, v]) => {
        if (/value[0-9]Type/.test(k)) {
            return evProps;
        }
        const regexParts = /value([0-9])$/.exec(k) || [];
        if (!regexParts[1]) {
            return Object.assign(Object.assign({}, evProps), { [k]: v });
        }
        /*
              IMPORTANT NOTE: Make sure parameters we are interested in (value1, value2, value3...) are
              mapped continuously in Matomo as dimensions when setting up because we are mapping these
              values to dimensions in continuous order and adds an offset(3) to disregard unwanted dimensions.
              ie: As of this implementation, our existing tracking events are mapped to dimension 4, 5, 6 in Matomo
                  to value1, value2, value3 respectively. Siddi adds the offset 3 to tracking data received from
                  clients(Nuclues, Phoenix, Gravity etc...) so the value1,2,3 is mapped to correct Matomo dimension
            */
        return Object.assign(Object.assign({}, evProps), { [`dimension${parseInt(regexParts[1]) + /* value-to-dimension mapping offset -> 3 */ 3}`]: v });
    }, {});
};
exports.prepareMatomoDimensions = prepareMatomoDimensions;
exports.DEFAULT_LOG_PREFIX = '[Siddi]';
const LOG_MSG = (message, prefix = exports.DEFAULT_LOG_PREFIX) => console.log(`${prefix}\t\t > ${message}`);
exports.LOG_MSG = LOG_MSG;
//# sourceMappingURL=utils.js.map